==> apache-wicket-6.30.0.zip: apache-wicket-6.30.0/wicket-core/src/test/java/org/apache/wicket/markup/html/basic/SimpleResponsePageClassTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.markup.html.basic;

import org.apache.wicket.WicketTestCase;
import org.apache.wicket.markup.html.form.Form;
import org.junit.Test;

/**
 * @author jcompagner
 * 
 */
public class SimpleResponsePageClassTest extends WicketTestCase
{
	/**
	 * @throws Exception
	 */
	@Test
	public void responsePageClass() throws Exception
	{
		tester.startPage(SimpleResponsePageClass.class);
		SimpleResponsePageClass manageBook = (SimpleResponsePageClass)tester.getLastRenderedPage();

		Form<?> form = (Form<?>)manageBook.get("form");

		tester.submitForm(form);

		// assertion failed, getLastRenderedPage() return null.
		assertTrue(tester.getLastRenderedPage() instanceof SimplePage);
	}
}

==> apache-wicket-8.17.0.zip: apache-wicket-8.17.0/wicket-core/src/test/java/org/apache/wicket/markup/html/basic/SimpleResponsePageClassTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.markup.html.basic;

import static org.hamcrest.CoreMatchers.instanceOf;

import org.apache.wicket.markup.html.form.Form;
import org.apache.wicket.util.tester.WicketTestCase;
import org.junit.Test;

/**
 * @author jcompagner
 * 
 */
public class SimpleResponsePageClassTest extends WicketTestCase
{
	/**
	 * @throws Exception
	 */
	@Test
	public void responsePageClass() throws Exception
	{
		tester.startPage(SimpleResponsePageClass.class);
		SimpleResponsePageClass manageBook = (SimpleResponsePageClass)tester.getLastRenderedPage();

		Form<?> form = (Form<?>)manageBook.get("form");

		tester.submitForm(form);

		// assertion failed, getLastRenderedPage() return null.
		assertThat(tester.getLastRenderedPage(), instanceOf(SimplePage.class));
	}
}
